
# StarSearch
[![License](https://img.shields.io/badge/license-MIT-blue.svg)](https://github.com/jdavidrcamacho/tedi/blob/master/LICENSE)


### Main files of StarSearch

`core.py` - file copied from astroquery to allow us to connect to the ESO archive

`phase3Archive.py` - file with the main functions to search and download reduced spectra from the ESO archive

`rawArchive.py` - file under development to search and download raw spectra from the ESO archive
 
 `utils.py` - file with some useful functions

----------

<img align="right" width="180" height="180" src="https://i.imgur.com/yhIts2Y.png">
